import { useCallback, useMemo } from "react";
import { useToast } from "../context/ToastContext";
import { get, post } from "../utils/axios";

const cdn = process.env.REACT_APP_CDN_URL;
const endpoints = {
  mimeTypes: `${cdn}/admin/mime-types`,
  resources: `${cdn}/admin/resources`
};

const useResourcesApi = () => {
  const { error } = useToast();

  const handleError = useCallback(
    (err) => {
      const message = `${err.title} ${err.correlationId}`;
      error(message);
    },
    [error]
  );

  const defaultOptions = useMemo(
    () => ({
      onCompleted: () => {},
      onError: handleError
    }),
    [handleError]
  );

  const call = useCallback(
    async (request, options) => {
      const internalOptions = { ...defaultOptions, ...options };
      const { onCompleted, onError } = internalOptions;

      try {
        const result = await request();
        onCompleted(result);
        return result;
      } catch (error) {
        onError(error);
        throw error;
      }
    },
    [defaultOptions]
  );

  const getMimeTypes = useCallback(
    (options = defaultOptions) => {
      const promise = call(() => get(endpoints.mimeTypes), options);
      return promise;
    },
    [call, defaultOptions]
  );

  return {
    getMimeTypes
  };
};

export default useResourcesApi;
